package fr.sanchezm.attestationsCovid19.data.db.dao

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.google.gson.Gson
import fr.sanchezm.attestationsCovid19.BuildConfig
import fr.sanchezm.attestationsCovid19.data.db.entity.Config
import java.io.File

class ConfigDao(private val savePath: String) {

    private val _config = MutableLiveData<Config>()
    private val fileName = "config.db"

    fun getConfig(): LiveData<Config> =
        _config

    fun updateConfig(config: Config) {
        _config.value = config
        save()
    }

    init {
        load()
    }

    private fun load() {
        val file = File("$savePath/$fileName")

        if (file.exists()) {
            _config.value = Gson().fromJson(file.readText(Charsets.UTF_8), Config::class.java)
            _config.value?.versionCode = BuildConfig.VERSION_CODE
            _config.value?.versionName = BuildConfig.VERSION_NAME
        } else {
            _config.value =
                Config(BuildConfig.DB_VERSION, BuildConfig.VERSION_NAME, BuildConfig.VERSION_CODE)
            save()
        }
    }

    private fun save() {
        File("$savePath/$fileName").writeText(Gson().toJson(_config.value))
    }

}